@@ -16,7 +16,7 @@ from torch.utils.checkpoint import checkpoint
 from .hf_model import PreTrainedTextEncoder
 from .modified_resnet import ModifiedResNet
 from .timm_model import TimmModel
-from .transformer import LayerNormFp32, QuickGELU, Attention, VisionTransformer, TextTransformer
+from .transformer import LayerNormFp32, LayerNorm, QuickGELU, Attention, VisionTransformer, TextTransformer
 from .utils import to_2tuple
 
 
@@ -45,6 +45,7 @@ class CLIPTextCfg:
     layers: int = 12
     ls_init_value: Optional[float] = None  # layer scale initial value
     hf_model_name: str = None
+    hf_tokenizer_name: str = None
     proj: str = 'mlp'
     pooler_type: str = 'mean_pooler'
 
@@ -94,7 +95,7 @@ def _build_vision_tower(
         )
     else:
         vision_heads = vision_cfg.width // vision_cfg.head_width
-        norm_layer = LayerNormFp32 if cast_dtype in (torch.float16, torch.bfloat16) else nn.LayerNorm
+        norm_layer = LayerNormFp32 if cast_dtype in (torch.float16, torch.bfloat16) else LayerNorm
         visual = VisionTransformer(
             image_size=vision_cfg.image_size,
             patch_size=vision_cfg.patch_size,
@@ -129,7 +130,7 @@ def _build_text_tower(
        )
     else:
         act_layer = QuickGELU if quick_gelu else nn.GELU
-        norm_layer = LayerNormFp32 if cast_dtype in (torch.float16, torch.bfloat16) else nn.LayerNorm
+        norm_layer = LayerNormFp32 if cast_dtype in (torch.float16, torch.bfloat16) else LayerNorm
 
         text = TextTransformer(
             context_length=text_cfg.context_length,
